import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class AddressInputModel {
  String? street;
  String? streetNumber;
  String? zipCode;
  String? city;
}

class AddressInput extends StatefulWidget {
  final AddressInputModel? address;

  const AddressInput({
    Key? key,
    this.address,
  }) : super(key: key);

  @override
  _AddressInputState createState() => _AddressInputState();
}

class _AddressInputState extends State<AddressInput> {
  late AddressInputModel _address;
  final _streetController = TextEditingController();
  final _streetNumberController = TextEditingController();
  final _zipController = TextEditingController();
  final _cityController = TextEditingController();
  late final void Function(String) onChanged;
  late int focusNo;
  late int previousFocusNo;

  @override
  void initState() {
    onChanged = (_) => setState(() {});
    focusNo = 0;
    previousFocusNo = 0;
    _address = widget.address ?? AddressInputModel();
    _streetNumberController.text = _address.streetNumber ?? '';
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.fromLTRB(10, 0, 10, 10),
      child: Column(
        children: [
          Row(
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.end,
            children: [
              Expanded(
                flex: 10,
                child: Focus(
                  onFocusChange: (value) => setFocus(value, 1),
                  child: TextFormField(
                    controller: _streetController,
                    onChanged: onChanged,
                    decoration: _getInputDecoration('Straße', _streetController, focusNo == 1),
                  ),
                ),
              ),
              Spacer(),
              Expanded(
                flex: 3,
                child: Focus(
                  onFocusChange: (value) => setFocus(value, 2),
                  child: TextFormField(
                    keyboardType: TextInputType.streetAddress,
                    controller: _streetNumberController,
                    onChanged: onChanged,
                    decoration: _getInputDecoration('Nr', _streetNumberController, focusNo == 2),
                  ),
                ),
              ),
            ],
          ),
          Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              Expanded(
                flex: 3,
                child: Focus(
                  onFocusChange: (value) => setFocus(value, 3),
                  child: TextFormField(
                    keyboardType: TextInputType.number,
                    controller: _zipController,
                    onChanged: onChanged,
                    decoration: _getInputDecoration('PLZ', _zipController, focusNo == 3),
                  ),
                ),
              ),
              Spacer(),
              Expanded(
                flex: 10,
                child: Focus(
                  onFocusChange: (value) => setFocus(value, 4),
                  child: TextFormField(
                    controller: _cityController,
                    onChanged: onChanged,
                    decoration: _getInputDecoration('Stadt', _cityController, focusNo == 4),
                  ),
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }

  InputDecoration _getInputDecoration(String hintText, TextEditingController controller, bool hasFocus) {
    return InputDecoration(
      labelText: hintText,
      suffixIconConstraints: BoxConstraints(maxHeight: 16),
      suffixIcon: controller.text.isNotEmpty && hasFocus
          ? IconButton(
              visualDensity: VisualDensity.compact,
              padding: EdgeInsets.zero,
              iconSize: 20,
              icon: Icon(Icons.close),
              onPressed: () {
                setState(() {
                  controller.clear();
                });
              },
            )
          : null,
    );
  }

  setFocus(bool hasFocus, int index) {
    print('previousFocusNo=$previousFocusNo $index $hasFocus');
    setState(() {
      if (hasFocus) {
        previousFocusNo = focusNo;
        focusNo = index;
      } else if (focusNo == previousFocusNo || previousFocusNo == 0) {
        focusNo = 0;
      } else {
        previousFocusNo = focusNo;
      }
    });
  }
}
