import 'package:dotup_flutter_widgets/themes/ThemeProvider.dart';
import 'package:dotup_flutter_widgets/scroll_wheel/ScrollWheel.dart';
import 'package:dotup_flutter_widgets_example/AddressInput.dart';
import 'package:dotup_flutter_widgets_example/GroupedListViewExample.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:provider/provider.dart';

import 'ListTiles.dart';

class SectionExamplePage extends StatefulWidget {
  const SectionExamplePage({
    Key? key,
  }) : super(key: key);

  @override
  _SectionExamplePageState createState() => _SectionExamplePageState();
}

class _SectionExamplePageState extends State<SectionExamplePage> {
  bool checkValue = false;
  bool switchValue = false;
  var groupValue = '1';
  String? dropdownValue;
  late String popupValue;
  bool dense = true;

  @override
  void initState() {
    popupValue = 'Popup menu button';
    super.initState();
  }

  @override
  build(BuildContext context) {
    final color = Theme.of(context).accentColor; // Colors.white70;
    final theme = Provider.of<ThemeProvider>(context, listen: false);

    const space = 4.0;

    return Scaffold(
      // title: 'zeiTick',
      // actions: [_buildAvatar(context)],
      // backgroundColor: Theme.of(context).buttonColor,
      // appBar: _buildAppBar(context),
      // body: _buildBody(context),
      // drawer: AppDrawer.standard(context),
      body: SafeArea(
        child: SectionView(
          padding: const EdgeInsets.fromLTRB(space, space, space, space),
          children: [
            Section(
              // margin: EdgeInsets.zero,
              header: SectionHeader(
                text: 'SectionHeader',
              ),
              children: [
                SectionTile(text: 'SectionTile', color: color, dense: dense),
                SectionTile.switchButton(
                  dense: dense,
                  text: 'Dark mode',
                  onChanged: (value) {
                    theme.switchTheme(value);
                  },
                  switchButtonValue: theme.isDarkMode,
                  color: color,
                ),
              ],
              footer: SectionFooter(text: 'SectionFooter'),
            ),
            Section(
              header: SectionHeader(
                text: 'Colors',
              ),
              children: [
                SectionTile.button(
                  text: 'Show color picker',
                  dense: dense,
                  onTap: () async {
                    final newColor = await showColorPickerPage(context, null, '');
                    theme.changePrimaryColor(newColor);
                    theme.changeAccentColor(newColor);
                  },
                  color: Colors.red,
                  icon: Icon(
                    Icons.delete,
                    color: Colors.red,
                  ),
                ),
                SectionTile.navigator(
                  text: 'Navigate to Color Palette',
                  color: color,
                  onTap: () async {
                    // final color = await Navigator.of(context).push(MaterialPageRoute(
                    //   builder: (context) => ColorSelectorPage(),
                    // ));
                    final color = await showColorSelectorPage(context);
                    print(color);
                  },
                  dense: dense,
                ),
              ],
            ),
            Section(
              header: SectionHeader(
                text: 'Wheels',
              ),
              children: [
                SectionTile.scrollWheelInfinite(
                  width: 50,
                  text: 'scrollWheelInfinite',
                  color: color,
                  items: List.generate(10, (index) => '$index-oha'),
                  onChange: (value) => print(value),
                  dense: dense,
                ),
                SectionTile.scrollWheelTimeSelector(
                  text: 'scrollWheelTimeSelector',
                  onChanged: (value) => print(value),
                  color: color,
                  dense: dense,
                ),
                Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Center(
                    child: ScrollWheel(
                      width: 50,
                      items: List.generate(10, (index) => '$index-oha'),
                      onChange: (value) => print(value),
                    ),
                  ),
                ),
              ],
            ),
            Section(
              header: SectionHeader(
                text: 'Buttons',
              ),
              children: [
                SectionTile.dropdownButton<String>(
                  text: 'Dropdown button',
                  color: color,
                  items: List.generate(4, (index) => 'Item $index'),
                  onChanged: (value) {
                    setState(() {
                      dropdownValue = value;
                    });
                  },
                  value: dropdownValue,
                  dense: dense,
                ),
                SectionTile.popupMenuButton<String>(
                  text: popupValue,
                  color: color,
                  items: List.generate(4, (index) => 'Item $index')..add('Popup menu button'),
                  // icon: Icon(Icons.arrow_drop_down),
                  onSelected: (value) {
                    setState(() {
                      popupValue = value;
                    });
                  },
                  initialValue: popupValue,
                  dense: dense,
                ),
                SectionTile.switchButton(
                  text: 'switchButton',
                  onChanged: switchChanged,
                  color: color,
                  activeColor: color,
                  switchButtonValue: switchValue,
                  dense: dense,
                ),
                SectionTile.switchButton(
                  text: 'switchButton',
                  onChanged: switchChanged,
                  color: color,
                  switchButtonValue: switchValue,
                  dense: dense,
                ),
                SectionTile.checkbox(
                    text: 'checkbox', onChanged: checkboxChanged, color: color, value: checkValue, dense: dense),
                SectionTile.checkbox(
                    text: 'checkbox', onChanged: checkboxChanged, color: color, value: checkValue, dense: dense),
                SectionTile.button(text: 'button', onTap: () {}, color: color, dense: dense),
                SectionTile.button(text: 'delete all', onTap: () {}, color: Colors.red, dense: dense),
                SectionTile.button(
                  text: 'Icon button',
                  onTap: () {},
                  color: Colors.red,
                  icon: Icon(
                    Icons.delete,
                    color: Colors.red,
                  ),
                ),
              ],
            ),
            Section(
              header: SectionHeader(
                text: 'Navigator',
              ),
              children: [
                SectionTile.navigator(
                  text: 'Navigate to GroupedListView',
                  color: color,
                  onTap: () async {
                    await Navigator.of(context).push(MaterialPageRoute(
                      builder: (context) => GroupedListViewExample(),
                    ));
                  },
                  dense: dense,
                ),
                SectionTile.navigator(
                  text: 'Navigate to ListTiles',
                  color: color,
                  onTap: () async {
                    await Navigator.of(context).push(MaterialPageRoute(
                      builder: (context) => ListTilesPage(),
                    ));
                  },
                  dense: dense,
                ),
                SectionTile(
                  text: 'text',
                  color: color,
                  icon: Icon(
                    Icons.delete,
                    color: Colors.red,
                  ),
                  dense: dense,
                ),
                SectionTile(
                  icon: Icon(Icons.place),
                  text: 'Arbeit',
                  dense: true,
                  color: color,
                  subTitle: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text('Industriering 7'),
                      Text('63868 Großwallstadt'),
                    ],
                  ),
                ),
              ],
              footer: SectionFooter(
                  text: 'Ein kleiner Hinweis zu dieser Sektion.. Dies ist ein langer Footer über mehrere Zeilen.'),
              // color: Colors.green,
            ),
            SectionGroup(
              header: SectionHeader(
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Text('Left'),
                    // Text('Left'),
                    TextButton.icon(
                      label: Icon(Icons.keyboard_arrow_right),
                      icon: Text('Alle'),
                      onPressed: () => print('object'),
                    ),
                  ],
                ),
              ),
              groupValue: groupValue,
              onChanged: (value) {
                setState(() {
                  groupValue = value.toString();
                });
                print(value);
              },
              children: [
                SectionGroupWidget(value: '1', child: Text('1')),
                SectionGroupWidget(value: '2', child: Text('2')),
                SectionGroupWidget(value: '3', child: Text('3')),
              ],
            ),
            Section(
              header: SectionHeader(
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.center,                  
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Text('Anschrift'),
                    // Text('Left'),
                    SizedBox(
                      height: 20,
                      child: IconButton(
                      
                        visualDensity: VisualDensity.compact,
                        padding: EdgeInsets.zero,
                        iconSize: 16,
                        icon: Icon(Icons.location_searching, color: color,),
                        onPressed: () => print('object'),
                      ),
                    ),
                  ],
                ),
              ),
              children: [
                SectionHeader(text: 'von:', color: color,),
                AddressInput(),
              ],
            ),
          ],
        ),
      ),
    );
  }

  Widget _getListTile({
    required String text,
    Widget? icon,
    VoidCallback? onTap,
    required Color color,
    Widget? subTitle,
  }) {
    return ListTile(
      leading: icon,
      title: Text(
        text,
        style: TextStyle(color: color),
      ),
      subtitle: subTitle,
      trailing: Icon(
        Icons.keyboard_arrow_right,
        color: color,
      ),
      onTap: onTap,
    );
  }

  void checkboxChanged(bool? value) {
    setState(() {
      checkValue = value!;
    });
  }

  void switchChanged(bool value) {
    setState(() {
      switchValue = value;
    });
  }
}
